@@ -151,6 +151,12 @@ gboolean            gsm_manager_is_inhibited                   (GsmManager
                                                                 gboolean              *is_inhibited,
                                                                 GError                *error);
 
+gboolean            gsm_manager_request_shutdown               (GsmManager     *manager,
+                                                                GError        **error);
+
+gboolean            gsm_manager_request_reboot                 (GsmManager     *manager,
+                                                                GError        **error);
+                                                                
 gboolean            gsm_manager_shutdown                       (GsmManager     *manager,
                                                                 GError        **error);
 
